==> jc-1.4.0.tar.gz: java/beans/beancontext/BeanContextServicesSupport__24BCSSServiceProvider.h <==
// public class java.beans.beancontext.BeanContextServicesSupport$BCSSServiceProvider

// class file dependencies
// @dep_class a8db56499cb98bc1 java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider_H_
#define _JC_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider_H_

// Forward structure declarations
struct _jc_java_beans_beancontext_BeanContextServiceProvider$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$sub_refs	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$sub_refs;
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$sub_nonrefs	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$sub_nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$refs	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$refs;
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$nonrefs	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$object	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$object;

typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$fields_struct	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$fields_struct;
typedef const struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vmethods	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vmethods;
typedef const struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vtable	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vtable;
typedef const struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vtype	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vtype;

// Class fields structure
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$fields_struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$class_fields;

// Constructors
extern void _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$object *);

// Virtual methods
extern struct _jc_object *_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$method$getServiceProvider$1241dcd258fd7b67(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$object *);

// Virtual method descriptors
extern _jc_method _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$method_info$getServiceProvider$1241dcd258fd7b67;

// Virtual methods structure
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vmethods {
	struct _jc_object	*(*getServiceProvider$1241dcd258fd7b67)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$object *);
};

// Vtable
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vmethods	java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider;
};

// Vtype
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vtype {
	_jc_type			type;
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$sub_refs {
	struct _jc_object	*serviceProvider;
};

// Reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$refs {
    _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$sub_refs	java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$sub_nonrefs	java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider;
};

// Object instance structure
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$object {
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vtype	*vtype;
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vtype _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$class_object;

#endif	/* _JC_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider_H_ */

==> jc-1.4.6.tar.gz: java/beans/beancontext/BeanContextServicesSupport__24BCSSServiceProvider.h <==
// public class java.beans.beancontext.BeanContextServicesSupport$BCSSServiceProvider

// class file dependencies
// @dep_class a8db56499cb98bc1 java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider_H_
#define _JC_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider_H_

// Forward structure declarations
struct _jc_java_beans_beancontext_BeanContextServiceProvider$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$sub_refs	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$sub_refs;
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$sub_nonrefs	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$sub_nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$refs	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$refs;
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$nonrefs	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$object	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$object;

typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$fields_struct	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$fields_struct;
typedef const struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vmethods	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vmethods;
typedef const struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vtable	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vtable;
typedef const struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vtype	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vtype;

// Class fields structure
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$fields_struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$class_fields;

// Constructors
extern void _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$method$getServiceProvider$1241dcd258fd7b67(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$method_info$getServiceProvider$1241dcd258fd7b67;

// Virtual methods structure
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vmethods {
	struct _jc_object	*(*getServiceProvider$1241dcd258fd7b67)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vmethods	java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider;
};

// Vtype
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vtype {
	_jc_type			type;
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$sub_refs {
	struct _jc_object	*serviceProvider;
};

// Reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$refs {
    _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$sub_refs	java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$sub_nonrefs	java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider;
};

// Object instance structure
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$object {
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vtype	*vtype;
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$vtype _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider$class_object;

#endif	/* _JC_java_beans_beancontext_BeanContextServicesSupport__24BCSSServiceProvider_H_ */
